@@ -1,3 +1,22 @@
+/*
+ *  Copyright 2010 Ruediger Gad
+ *
+ *  This file is part of vumeter.
+ *
+ *  vumeter is free software: you can redistribute it and/or modify
+ *  it under the terms of the GNU General Public License as published by
+ *  the Free Software Foundation, either version 3 of the License, or
+ *  (at your option) any later version.
+ *
+ *  vumeter is distributed in the hope that it will be useful,
+ *  but WITHOUT ANY WARRANTY; without even the implied warranty of
+ *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ *  GNU General Public License for more details.
+ *
+ *  You should have received a copy of the GNU General Public License
+ *  along with vumeter.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
 #include "mainwindow.h"
 #include "ui_mainwindow.h"
 
@@ -38,29 +57,22 @@ MainWindow::~MainWindow()
 }
 
 void MainWindow::resetMaxValue(){
-    if(ui->linearRadioButton->isChecked()){
-        maxVol = 0;
-    }else if(ui->dBRadioButton->isChecked()){
-        maxVol = MIN_DB;
-    }
-
+    maxVol = 0;
     ui->maximumVolume->setNum(maxVol);
 }
 
 void MainWindow::setDbScale(){
-    ui->volumeBar->setMinimum(-70);
-    ui->volumeBar->setMaximum(5);
+    ui->volumeBar->setMinimum(0);
+    ui->volumeBar->setMaximum(110);
 
-    maxVol = MIN_DB;
-    ui->maximumVolume->setNum(maxVol);
+    resetMaxValue();
 }
 
 void MainWindow::setLinearScale(){
     ui->volumeBar->setMinimum(0);
-    ui->volumeBar->setMaximum(100);
+    ui->volumeBar->setMaximum(200);
 
-    maxVol = 0;
-    ui->maximumVolume->setNum(maxVol);
+    resetMaxValue();
 }
 
 void MainWindow::sourceChanged(QString source){
@@ -75,10 +87,10 @@ void MainWindow::updateValues(float value){
     if(ui->linearRadioButton->isChecked()){
         vol = 100 * value;
     }else if(ui->dBRadioButton->isChecked()){
-        vol = (int) pa_sw_volume_to_dB(pa_sw_volume_from_linear((double)value));
+        vol = (int) 100 + pa_sw_volume_to_dB(pa_sw_volume_from_linear((double)value));
     }
 
-    if(vol < MIN_DB){
+    if(vol < 0){
         return;
     }
 
@@ -93,9 +105,7 @@ void MainWindow::updateValues(float value){
 void MainWindow::updateVuMeter(const float *data){
     float vol = *data;
 
-    if(vol >= 0 && vol < 1){
-        emit updateVuMeterSignal(vol);
-    }
+    emit updateVuMeterSignal(vol);
 }
 
 
